@@ -5,7 +5,7 @@
 
     Utility functions for docutils.
 
-    :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2019 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 from __future__ import absolute_import
@@ -131,7 +131,7 @@ def using_user_docutils_conf(confdir):
         yield
     finally:
         if docutilsconfig is None:
-            os.environ.pop('DOCUTILSCONFIG')
+            os.environ.pop('DOCUTILSCONFIG', None)
         else:
             os.environ['DOCUTILSCONFIG'] = docutilsconfig
 
@@ -226,13 +226,13 @@ class sphinx_domains(object):
 class WarningStream(object):
     def write(self, text):
         # type: (unicode) -> None
-        matched = report_re.search(text)  # type: ignore
+        matched = report_re.search(text)
         if not matched:
             logger.warning(text.rstrip("\r\n"))
         else:
             location, type, level = matched.groups()
-            message = report_re.sub('', text).rstrip()  # type: ignore
-            logger.log(type, message, location=location)
+            message = report_re.sub('', text).rstrip()
+            logger.log(type, message, location=location)  # type: ignore
 
 
 class LoggingReporter(Reporter):
